@@ -62,6 +62,9 @@ class Hosts(object):
             del self.hosts[name]
         self.save()
 
+    def info(self, host):
+        return f'{host} ip={self.get_ip(host)} port={self.get_port(host)}'
+
 
 class DotEnough(object):
 
@@ -134,6 +137,16 @@ class DotEnough(object):
         """))
 
 
+class DotEnoughLibvirt(DotEnough):
+
+    def __init__(self, config_dir, domain):
+        super().__init__(config_dir, domain)
+
+    def ensure(self):
+        super().ensure()
+        self.populate_config('ownca')
+
+
 class DotEnoughOpenStackUnknownProvider(Exception):
     pass
 
@@ -180,10 +193,3 @@ class DotEnoughOpenStack(DotEnough):
         openstack_provider: {provider}
         """))
         return f
-
-
-class DotEnoughDocker(DotEnough):
-
-    def ensure(self):
-        super().ensure()
-        self.populate_config('ownca')
