@@ -7,7 +7,6 @@ import os
 import re
 import requests
 import sh
-import socket
 import textwrap
 import time
 import yaml
@@ -16,6 +15,7 @@ from enough import settings
 from enough.common import ansible_utils
 from enough.common.retry import retry
 from enough.common.dotenough import Hosts
+from enough.common.ssh import SSH
 
 log = logging.getLogger(__name__)
 
@@ -38,16 +38,6 @@ class OpenStackBase(object):
             _env={'OS_CLIENT_CONFIG_FILE': self.config_file},
         )
 
-    @staticmethod
-    @retry((socket.timeout, ConnectionRefusedError, OSError), 9)
-    def wait_for_ssh(ip, port):
-        log.info('Check if SSH is available on %s:%s', ip, port)
-        s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-        s.settimeout(5)
-        s.connect((ip, int(port)))
-        line = s.makefile("rb").readline()
-        assert line.startswith(b'SSH-')
-
 
 class Stack(OpenStackBase):
 
@@ -113,7 +103,7 @@ class Stack(OpenStackBase):
             'port': self.definition['port'],
         }
         if not self.internal_only() or self.args.get('route_to_internal', True):
-            self.wait_for_ssh(info['ipv4'], info['port'])
+            SSH.wait_for_ssh(info['ipv4'], info['port'])
         Hosts(self.config_dir).create_or_update(
             self.definition['name'], info['ipv4'], info['port'])
         return info
@@ -200,14 +190,6 @@ class Heat(OpenStackBase):
 
     @staticmethod
     def hostvars_to_stack(host, hv):
-        if hv.get('network_internal_only'):
-            network_interface_unconfigured = hv['network_primary_interface']
-            network_interface_routed = hv['network_secondary_interface']
-            network_interface_not_routed = 'noname'
-        else:
-            network_interface_unconfigured = 'noname'
-            network_interface_routed = hv['network_primary_interface']
-            network_interface_not_routed = hv['network_secondary_interface']
         definition = {
             'name': host,
             'port': hv.get('ansible_port', '22'),
@@ -215,9 +197,9 @@ class Heat(OpenStackBase):
             'image': hv['openstack_image'],
             'network': hv.get('openstack_network'),
             'network_internal_only': hv.get('network_internal_only'),
-            'network_interface_unconfigured': network_interface_unconfigured,
-            'network_interface_routed': network_interface_routed,
-            'network_interface_not_routed': network_interface_not_routed,
+            'network_interface_unconfigured': hv.get('network_interface_unconfigured'),
+            'network_interface_routed': hv.get('network_interface_routed'),
+            'network_interface_not_routed': hv.get('network_interface_not_routed'),
             'internal_network': OpenStackBase.INTERNAL_NETWORK,
             'internal_network_cidr': hv.get('openstack_internal_network_cidr',
                                             OpenStackBase.INTERNAL_NETWORK_CIDR),
@@ -335,7 +317,7 @@ class OpenStack(OpenStackBase):
         super().__init__(config_dir, **kwargs)
         self.config = yaml.safe_load(open(self.config_file))
 
-    @retry(OpenStackLeftovers, tries=7)
+    @retry(OpenStackLeftovers, tries=8)
     def destroy_everything(self, prefix):
         log.info('destroy_everything acting')
         leftovers = []
