@@ -1,7 +1,12 @@
+import logging
+import socket
 import subprocess
 import sys
 
 from enough.common import dotenough
+from enough.common.retry import retry
+
+log = logging.getLogger(__name__)
 
 
 class SSH(object):
@@ -29,3 +34,13 @@ class SSH(object):
         else:
             kwargs = dict(capture_output=True)
         return subprocess.run(ssh + args, **kwargs)
+
+    @staticmethod
+    @retry((socket.timeout, ConnectionRefusedError, OSError), 8)
+    def wait_for_ssh(ip, port):
+        log.info('Check if SSH is available on %s:%s', ip, port)
+        s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+        s.settimeout(5)
+        s.connect((ip, int(port)))
+        line = s.makefile("rb").readline()
+        assert line.startswith(b'SSH-')
