@@ -3,7 +3,8 @@ testinfra_hosts = ['ansible://bind-host']
 
 def expected_backups(host, count):
     cmd = host.run("""
-    . /usr/lib/backup/openrc.sh
+    export OS_CLIENT_CONFIG_FILE=/usr/lib/backup/clouds.yml
+    export OS_CLOUD=production
     openstack ${OS_INSECURE} image list | grep -c pet-host
     """)
     print(cmd.stderr)
@@ -17,11 +18,7 @@ def test_backup(host):
     # SSL exception connecting to
     #    https://auth.cloud.ovh.net/v2.0/tokens: [SSL: CERTIFICATE_VERIFY_FAILED]
     with host.sudo():
-        cmd = host.run("echo export OS_INSECURE=--insecure >> /usr/lib/backup/openrc.sh")
-        print(cmd.stdout)
-        print(cmd.stderr)
-        assert 0 == cmd.rc
-        cmd = host.run("/etc/cron.daily/prune-backup 0")
+        cmd = host.run("OS_INSECURE=--insecure /etc/cron.daily/prune-backup 0")
         print(cmd.stdout)
         print(cmd.stderr)
         assert 0 == cmd.rc
@@ -29,6 +26,7 @@ def test_backup(host):
             host.run("timedatectl set-ntp 0")
             cmd = host.run("""
             set -x
+            export OS_INSECURE=--insecure
             date -s '-15 days'
             bash -x /etc/cron.daily/backup
             date -s '-30 days'
@@ -39,8 +37,8 @@ def test_backup(host):
             print(cmd.stderr)
             assert 0 == cmd.rc
             expected_backups(host, '2')
-            host.run("bash -x /etc/cron.daily/prune-backup 30")
+            host.run("OS_INSECURE=--insecure bash -x /etc/cron.daily/prune-backup 30")
             expected_backups(host, '1')
         finally:
             host.run("timedatectl set-ntp 1")
-            host.run("bash -x /etc/cron.daily/prune-backup 0")
+            host.run("OS_INSECURE=--insecure bash -x /etc/cron.daily/prune-backup 0")
