@@ -10,8 +10,7 @@ def test_sshfp(host):
     #       vars:
     #         install_ssh_records_host: lab
     #
-    cmd = host.run('dig sshfp +noall +answer @ns1.{domain} lab.{domain}'.format(
-        domain=domain))
+    cmd = host.run(f'dig sshfp +noall +answer @ns1.{domain} lab.{domain}')
     assert cmd.rc == 0
-    assert 'IN SSHFP' in cmd.stdout
+    assert 'SSHFP' in cmd.stdout
     assert 'lab.' + domain in cmd.stdout
