@@ -8,8 +8,7 @@ IcingaHelper.icinga_host = 'bind-host'
 class TestChecks(IcingaHelper):
 
     def test_host(self):
-        r = self.get_client().objects.get('Host', 'wazuh-host')
-        assert r['attrs']['name'] == 'wazuh-host'
+        assert 'wazuh-host' in self.get_hosts(host='wazuh-host')
 
     def test_service(self, host):
         assert self.is_service_ok('wazuh-host!ping4')
